@@ -3,24 +3,25 @@ use utf8;
 use strict;
 use warnings FATAL => 'all';
 
-use Muldis::Rosetta::Interface 0.013003;
+use Muldis::Rosetta::Interface 0.014000;
 
-#use Muldis::Rosetta::Engine::Example::Value 0.013003;
-#use Muldis::Rosetta::Engine::Example::Routines 0.013003;
-#use Muldis::Rosetta::Engine::Example::Storage 0.013003;
-#use Muldis::Rosetta::Engine::Example::Runtime 0.013003;
-#use Muldis::Rosetta::Engine::Example::Util 0.013003;
-#use Muldis::Rosetta::Engine::Example::PlainText 0.013003;
-#use Muldis::Rosetta::Engine::Example::HostedData 0.013003;
+#use Muldis::Rosetta::Engine::Example::Value 0.014000;
+#use Muldis::Rosetta::Engine::Example::Routines 0.014000;
+#use Muldis::Rosetta::Engine::Example::Storage 0.014000;
+#use Muldis::Rosetta::Engine::Example::Runtime 0.014000;
+#use Muldis::Rosetta::Engine::Example::Util 0.014000;
+#use Muldis::Rosetta::Engine::Example::PlainText 0.014000;
+#use Muldis::Rosetta::Engine::Example::HostedData 0.014000;
 
 ###########################################################################
 ###########################################################################
 
 { package Muldis::Rosetta::Engine::Example; # module
-    use version 0.74; our $VERSION = qv('0.13.3');
+    our $VERSION = '0.014000';
+    $VERSION = eval $VERSION;
     # Note: This given version applies to all of this file's packages.
 
-    use namespace::clean;
+    use namespace::autoclean 0.08;
 
 ###########################################################################
 
@@ -37,9 +38,9 @@ sub new_machine {
 
 { package Muldis::Rosetta::Engine::Example::Public::Machine; # class
 
-    use MooseX::Singleton 0.17;
+    use namespace::autoclean 0.08;
 
-    use namespace::clean -except => 'meta';
+    use MooseX::Singleton 0.18;
 
     with 'Muldis::Rosetta::Interface::Machine';
 
@@ -71,9 +72,9 @@ sub new_process {
 
 { package Muldis::Rosetta::Engine::Example::Public::Process; # class
 
-    use Moose 0.79;
+    use namespace::autoclean 0.08;
 
-    use namespace::clean -except => 'meta';
+    use Moose 0.89;
 
     has 'assoc_machine' => (
         is       => 'ro',
@@ -221,10 +222,10 @@ sub upd_invo {
     return;
 }
 
-sub proc_invo {
+sub imp_invo {
     my ($self, $args) = @_;
-    my ($procedure, $upd_args, $ro_args, $pt_lang, $hd_lang) = @{$args}{
-        'procedure', 'upd_args', 'ro_args', 'pt_lang', 'hd_lang'};
+    my ($imperative, $upd_args, $ro_args, $pt_lang, $hd_lang) = @{$args}{
+        'imperative', 'upd_args', 'ro_args', 'pt_lang', 'hd_lang'};
 
     # TODO, the real work
 
@@ -242,9 +243,9 @@ sub proc_invo {
 
 { package Muldis::Rosetta::Engine::Example::Public::Value; # class
 
-    use Moose 0.79;
+    use namespace::autoclean 0.08;
 
-    use namespace::clean -except => 'meta';
+    use Moose 0.89;
 
     has 'assoc_process' => (
         is       => 'ro',
@@ -348,7 +349,7 @@ Self-contained reference implementation of a Muldis Rosetta Engine
 
 =head1 VERSION
 
-This document describes Muldis::Rosetta::Engine::Example version 0.13.3 for
+This document describes Muldis::Rosetta::Engine::Example version 0.14.0 for
 Perl 5.
 
 It also describes the same-number versions for Perl 5 of
@@ -475,7 +476,7 @@ Example written in any of the following:
 See L<Muldis::D::Dialect::PTMD_STD> for details.
 
 The language name is specified as a Perl character string whose value is
-C<Muldis_D:"http://muldis.com":"0.75.0":PTMD_STD>.  No other version
+C<Muldis_D:"http://muldis.com":"0.85.0":PTMD_STD>.  No other version
 numbers are currently supported.
 
 =item B<Tiny Perl Hosted Data Muldis D>
@@ -483,7 +484,7 @@ numbers are currently supported.
 See L<Muldis::D::Dialect::HDMD_Perl5_STD> for details.
 
 The language name is specified either as a Perl array whose value is C<[
-'Muldis_D', 'http://muldis.com', '0.75.0', 'HDMD_Perl5_STD' ]>.  No other
+'Muldis_D', 'http://muldis.com', '0.85.0', 'HDMD_Perl5_STD' ]>.  No other
 version numbers are currently supported.
 
 =back
@@ -503,21 +504,16 @@ I<This documentation is pending.>
 The Muldis Rosetta Example Engine, meaning the collection of files that
 includes this file and all other C<Muldis::Rosetta::Engine::Example::\w+>
 files, requires any version of Perl 5.x.y that is at least 5.8.1, and
-recommends one that is at least 5.10.0.
-
-It also requires these Perl 5 packages that are bundled with any version of
-Perl 5.x.y that is at least 5.10.0, and are also on CPAN for separate
-installation by users of earlier Perl versions:
-L<version-ver(0.74..*)|version>.
+recommends one that is at least 5.10.1.
 
 It also requires these Perl 5 packages that are on CPAN:
-L<namespace::clean-ver(0.11..*)|namespace::clean>,
-L<Moose-ver(0.79..*)|Moose>, L<Moose::Role-ver(0.79..*)|Moose::Role>,
-L<MooseX::Singleton-ver(0.17..*)|MooseX::Singleton>.
+L<namespace::autoclean-ver(0.08..*)|namespace::autoclean>,
+L<Moose-ver(0.89..*)|Moose>, L<Moose::Role-ver(0.89..*)|Moose::Role>,
+L<MooseX::Singleton-ver(0.18..*)|MooseX::Singleton>.
 
 It also requires these Perl 5 packages that are in the current
 distribution:
-L<Muldis::Rosetta::Interface-ver(0.13.3..*)|Muldis::Rosetta::Interface>.
+L<Muldis::Rosetta::Interface-ver(0.14.0..*)|Muldis::Rosetta::Interface>.
 
 =head1 INCOMPATIBILITIES
 
