@@ -7,14 +7,15 @@ use warnings FATAL => 'all';
 ###########################################################################
 
 { package Muldis::Rosetta::Interface; # module
-    use version 0.74; our $VERSION = qv('0.13.3');
+    our $VERSION = '0.014000';
+    $VERSION = eval $VERSION;
     # Note: This given version applies to all of this file's packages.
 
+    use namespace::autoclean 0.08;
+
     use Carp;
     use Scalar::Util 'blessed';
 
-    use namespace::clean;
-
 ###########################################################################
 
 sub new_machine {
@@ -74,9 +75,9 @@ sub new_machine {
 
 { package Muldis::Rosetta::Interface::Machine; # role
 
-    use Moose::Role 0.79;
+    use namespace::autoclean 0.08;
 
-    use namespace::clean -except => 'meta';
+    use Moose::Role 0.89;
 
     requires 'new_process';
 
@@ -87,9 +88,9 @@ sub new_machine {
 
 { package Muldis::Rosetta::Interface::Process; # role
 
-    use Moose::Role 0.79;
+    use namespace::autoclean 0.08;
 
-    use namespace::clean -except => 'meta';
+    use Moose::Role 0.89;
 
     requires 'assoc_machine';
     requires 'pt_command_lang';
@@ -100,7 +101,7 @@ sub new_machine {
     requires 'new_value';
     requires 'func_invo';
     requires 'upd_invo';
-    requires 'proc_invo';
+    requires 'imp_invo';
     requires 'trans_nest_level';
     requires 'start_trans';
     requires 'commit_trans';
@@ -113,9 +114,9 @@ sub new_machine {
 
 { package Muldis::Rosetta::Interface::Value; # role
 
-    use Moose::Role 0.79;
+    use namespace::autoclean 0.08;
 
-    use namespace::clean -except => 'meta';
+    use Moose::Role 0.89;
 
     requires 'assoc_process';
     requires 'pt_source_code';
@@ -140,7 +141,7 @@ Common public API for Muldis Rosetta Engines
 
 =head1 VERSION
 
-This document describes Muldis::Rosetta::Interface version 0.13.3 for Perl
+This document describes Muldis::Rosetta::Interface version 0.14.0 for Perl
 5.
 
 It also describes the same-number versions for Perl 5 of
@@ -160,7 +161,7 @@ producing a third Perl variable holding the relation data of the result.
         'engine_name' => 'Muldis::Rosetta::Engine::Example' });
     my $process = $machine->new_process();
     $process->update_hd_command_lang({ 'lang' => [ 'Muldis_D',
-        'http://muldis.com', '0.75.0', 'HDMD_Perl5_STD' ] });
+        'http://muldis.com', '0.85.0', 'HDMD_Perl5_STD' ] });
 
     my $r1 = $process->new_value({
         'source_code' => [ 'Relation', [ [ 'x', 'y' ] => [
@@ -180,7 +181,7 @@ producing a third Perl variable holding the relation data of the result.
     my $r3 = $process->func_invo({
         'function' => 'join',
         'args' => {
-            'topic' => [ 'QSet', [ $r1, $r2 ] ],
+            'topic' => [ 'Set', [ $r1, $r2 ] ],
         }
     });
 
@@ -407,18 +408,19 @@ subject-to-update parameter; said Perl variable is then what holds a
 C<Value> object et al prior to the updater's execution, and that may have
 been updated to hold a different C<Value> object as a side-effect.
 
-=head2 proc_invo
+=head2 imp_invo
 
-C<method proc_invo ($self: Str :$procedure!, Hash :$upd_args?, Hash
+C<method imp_invo ($self: Str :$imperative!, Hash :$upd_args?, Hash
 :$ro_args?, Str :$pt_lang?, Array :$hd_lang?)>
 
-This method invokes the Muldis D procedure (or system_service) named by its
-C<$procedure> argument, giving it subject-to-update arguments from
-C<$upd_args> and read-only arguments from C<$ro_args>; the C<Value> objects
-in C<$upd_args> are possibly substituted for other C<Value> objects as a
-side-effect of the procedure's execution.  The parameters of C<proc_invo>
-are as per those of the C<upd_invo> method, save that only C<upd_invo>
-makes C<$upd_args> mandatory, while C<proc_invo> makes it optional.
+This method invokes the Muldis D imperative routine (procedure, system
+service, or updater) named by its C<$imperative> argument, giving it
+subject-to-update arguments from C<$upd_args> and read-only arguments from
+C<$ro_args>; the C<Value> objects in C<$upd_args> are possibly substituted
+for other C<Value> objects as a side-effect of the routine's execution.
+The parameters of C<imp_invo> are as per those of the C<upd_invo> method,
+save that only C<upd_invo> makes C<$upd_args> mandatory, while C<imp_invo>
+makes it optional.
 
 =head2 trans_nest_level
 
@@ -513,16 +515,11 @@ I<This documentation is pending.>
 =head1 DEPENDENCIES
 
 This file requires any version of Perl 5.x.y that is at least 5.8.1, and
-recommends one that is at least 5.10.0.
-
-It also requires these Perl 5 packages that are bundled with any version of
-Perl 5.x.y that is at least 5.10.0, and are also on CPAN for separate
-installation by users of earlier Perl versions:
-L<version-ver(0.74..*)|version>.
+recommends one that is at least 5.10.1.
 
 It also requires these Perl 5 packages that are on CPAN:
-L<namespace::clean-ver(0.11..*)|namespace::clean>,
-L<Moose::Role-ver(0.79..*)|Moose::Role>.
+L<namespace::autoclean-ver(0.08..*)|namespace::autoclean>,
+L<Moose::Role-ver(0.89..*)|Moose::Role>.
 
 =head1 INCOMPATIBILITIES
 
